@@ -39,7 +39,6 @@ PyObject *extension_blend_images(PyObject *self, PyObject *args) {
     } else {
         VALIDATE_A(blend_images(&bottom, &top, algorithm), Py_RETURN_NONE);
     }
-
     VALIDATE_A(write_png(&bottom, demultiply, target_path), Py_RETURN_NONE);
     VALIDATE_A(release_image(&top), Py_RETURN_NONE);
     VALIDATE_A(release_image(&bottom), Py_RETURN_NONE);
@@ -48,12 +47,11 @@ PyObject *extension_blend_images(PyObject *self, PyObject *args) {
 };
 
 PyObject *extension_blend_multiple(PyObject *self, PyObject *args) {
-    int run_inline, cache, destroy_struct;
+    int run_inline;
     char demultiply, source_over;
     char *bottom_path, *top_path, *target_path, *algorithm;
     struct pcv_image bottom, top;
-    struct pcv_image *bottom_cache, *top_cache;
-    PyObject *paths, *iterator, *element, *first, *second, *is_inline, *use_cache;
+    PyObject *paths, *iterator, *element, *first, *second, *is_inline;
     Py_ssize_t size;
 
 #if PY_MAJOR_VERSION >= 3
@@ -62,20 +60,17 @@ PyObject *extension_blend_multiple(PyObject *self, PyObject *args) {
 
     if(PyArg_ParseTuple(
         args,
-        "Os|sOO",
+        "Os|sO",
         &paths,
         &target_path,
         &algorithm,
-        &is_inline,
-        &use_cache
+        &is_inline
     ) == 0) { return NULL; }
 
     algorithm = algorithm == NULL ? "multiplicative" : algorithm;
-    run_inline = is_inline != NULL && PyObject_IsTrue(is_inline) == TRUE ? TRUE : FALSE;
-    cache = use_cache != NULL && PyObject_IsTrue(use_cache) == TRUE ? TRUE : FALSE;
+    run_inline = is_inline == NULL ? 0 : PyBool_Check(is_inline);
     demultiply = is_multiplied(algorithm);
     source_over = strcmp(algorithm, "source_over") == 0;
-    destroy_struct = cache == TRUE ? FALSE : TRUE;
 
     size = PyList_Size(paths);
     if(size < 2) { Py_RETURN_NONE; }
@@ -93,31 +88,8 @@ PyObject *extension_blend_multiple(PyObject *self, PyObject *args) {
     top_path = PyString_AsString(second);
 #endif
 
-    bottom_cache = (struct pcv_image *) value_map(bottom_path);
-    if(cache && bottom_cache != NULL) {
-        VALIDATE_A(duplicate_image(bottom_cache, &bottom), Py_RETURN_NONE);
-    } else {
-        VALIDATE_A(read_png(bottom_path, demultiply, &bottom), Py_RETURN_NONE);
-    }
-
-    top_cache = (struct pcv_image *) value_map(top_path);
-    if(cache && top_cache != NULL ) {
-        VALIDATE_A(duplicate_image(top_cache, &top), Py_RETURN_NONE);
-    } else {
-        VALIDATE_A(read_png(top_path, demultiply, &top), Py_RETURN_NONE);
-    }
-
-    if(cache && bottom_cache == NULL) {
-        bottom_cache = malloc(sizeof(struct pcv_image));
-        duplicate_image(&bottom, bottom_cache);
-        set_map(bottom_path, bottom_cache);
-    }
-    if(cache && top_cache == NULL) {
-        top_cache = malloc(sizeof(struct pcv_image));
-        duplicate_image(&top, top_cache);
-        set_map(top_path, top_cache);
-    }
-
+    VALIDATE_A(read_png(bottom_path, demultiply, &bottom), Py_RETURN_NONE);
+    VALIDATE_A(read_png(top_path, demultiply, &top), Py_RETURN_NONE);
     if(source_over == TRUE) {
         VALIDATE_A(blend_images_fast(&bottom, &top, algorithm), Py_RETURN_NONE);
     } else if(run_inline == TRUE) {
@@ -125,7 +97,7 @@ PyObject *extension_blend_multiple(PyObject *self, PyObject *args) {
     } else {
         VALIDATE_A(blend_images(&bottom, &top, algorithm), Py_RETURN_NONE);
     }
-    VALIDATE_A(release_image_s(&top, destroy_struct), Py_RETURN_NONE);
+    VALIDATE_A(release_image(&top), Py_RETURN_NONE);
 
 #if PY_MAJOR_VERSION >= 3
     Py_DECREF(first);
@@ -146,21 +118,7 @@ PyObject *extension_blend_multiple(PyObject *self, PyObject *args) {
 #else
         top_path = PyString_AsString(element);
 #endif
-
-        top_cache = (struct pcv_image *) value_map(top_path);
-        if(cache && top_cache != NULL) {
-            VALIDATE_A(duplicate_image(top_cache, &top), Py_RETURN_NONE);
-        } else {
-            VALIDATE_A(read_png(top_path, demultiply, &top), Py_RETURN_NONE);
-        }
         VALIDATE_A(read_png(top_path, demultiply, &top), Py_RETURN_NONE);
-
-        if(cache && top_cache == NULL) {
-            top_cache = malloc(sizeof(struct pcv_image));
-            duplicate_image(&top, top_cache);
-            set_map(top_path, top_cache);
-        }
-
         if(source_over == TRUE) {
             VALIDATE_A(blend_images_fast(&bottom, &top, algorithm), Py_RETURN_NONE);
         } else if(run_inline == TRUE) {
@@ -168,7 +126,7 @@ PyObject *extension_blend_multiple(PyObject *self, PyObject *args) {
         } else {
             VALIDATE_A(blend_images(&bottom, &top, algorithm), Py_RETURN_NONE);
         }
-        VALIDATE_A(release_image_s(&top, destroy_struct), Py_RETURN_NONE);
+        VALIDATE_A(release_image(&top), Py_RETURN_NONE);
         Py_DECREF(element);
 #if PY_MAJOR_VERSION >= 3
         Py_DECREF(encoded);
@@ -178,7 +136,7 @@ PyObject *extension_blend_multiple(PyObject *self, PyObject *args) {
     Py_DECREF(iterator);
 
     VALIDATE_A(write_png(&bottom, demultiply, target_path), Py_RETURN_NONE);
-    VALIDATE_A(release_image_s(&bottom, destroy_struct), Py_RETURN_NONE);
+    VALIDATE_A(release_image(&bottom), Py_RETURN_NONE);
 
     Py_RETURN_NONE;
 };
@@ -220,29 +178,29 @@ PyMethodDef pconvert_functions[4] = {
 
 #if PY_MAJOR_VERSION >= 3
 PyMODINIT_FUNC PyInit_pconvert(void) {
-    // allocates space for the module object to hold the
-    // module to be created
+    /* allocates space for the module object to hold the
+    module to be created */
     PyObject *pconvert_module;
 
-    // creates the pconvert extension module with the
-    // functions defined in the previous array, in case
-    // no module is created the control flow is returned
-    // immediately to the caller function
+    /* creates the pconvert extension module with the
+    functions defined in the previous array, in case
+    no module is created the control flow is returned
+    immediately to the caller function */
     pconvert_module = PyModule_Create(&moduledef);
     if(pconvert_module == NULL) { return NULL; }
 
-    // returns the module that has just been created to
-    // the caller method/function (to be used)
+    /* returns the module that has just been created to
+    the caller method/function (to be used) */
     return pconvert_module;
 }
 #else
 PyMODINIT_FUNC initpconvert(void) {
-    // allocates space for the module object to hold the
-    // module to be created
+    /* allocates space for the module object to hold the
+    module to be created */
     PyObject *pconvert_module;
 
-    // creates the pconvert extension module with the
-    // functions defined in the previous array
+    /* creates the pconvert extension module with the
+    functions defined in the previous array */
     pconvert_module = Py_InitModule("pconvert", pconvert_functions);
     if(pconvert_module == NULL) { return; }
 }
